<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>Cmd</name>
    <message>
        <location filename="../cmd.cpp" line="141"/>
        <source>Administrator Access Required</source>
        <translation>O acesso com as permissões de administrador é necessário</translation>
    </message>
    <message>
        <location filename="../cmd.cpp" line="142"/>
        <source>This operation requires administrator privileges. Please restart the application and enter your password when prompted.</source>
        <translation>Esta operação requer as permissões ou os privilégios de administrador. Por favor, reinicie o programa e digite a sua senha quando for solicitada.</translation>
    </message>
</context>
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Foi detectado o ambiente de um sistema operacional iniciado a
partir de um dispositivo executável (CD, DVD, USB, etc.). Por favor,
selecione a partição raiz (root) do sistema que você quer modificar,
apenas as partições do GNU/Linux são exibidas</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>Aceitar</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Utilizar uma de estrutura de menus simplificada sem os submenus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="42"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Utilizar os menus condensados (sem os submenus)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Boot to</source>
        <translation>Iniciar por</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="78"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Ajuste para ‘0’ para iniciar imediatamente sem exibir o menu, ou, para ‘-1’ para aguardar indefinidamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Menu timeout</source>
        <translation>Tempo de espera do menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Kernel parameters</source>
        <translation>Parâmetros do Núcleo (Kernel)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Com esta opção ativada, qualquer entrada que você selecionar no menu de inicialização do Grub será salva como o novo padrão para as inicializações futuras</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Enable saving last boot choice</source>
        <translation>Ativar o salvamento da última escolha de inicialização</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="134"/>
        <source>Manage UEFI Boot Options</source>
        <translation>Gerenciar as Opções de Inicialização do UEFI</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Background</source>
        <translation>Tela de fundo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Image</source>
        <translation>Imagem</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Enable theme</source>
        <translation>Ativar o tema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Splash</source>
        <translation>Tela de início</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>Preview</source>
        <translation>Pré-visualização</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>Messages</source>
        <translation>Mensagens</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Very detailed</source>
        <translation>Bem detalhado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Detailed (default setting)</source>
        <translation>Detalhado (é a configuração padrão)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="342"/>
        <source>Limited</source>
        <translation>Limitado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>Display log</source>
        <translation>Exibir o relatório das alterações</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Display help </source>
        <translation>Exibir ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="453"/>
        <source>About this application</source>
        <translation>Sobre este programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>Quit application</source>
        <translation>Sair do programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="501"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="99"/>
        <source>Still running</source>
        <translation>Ainda está executando</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="373"/>
        <location filename="../mainwindow.cpp" line="381"/>
        <location filename="../mainwindow.cpp" line="415"/>
        <location filename="../mainwindow.cpp" line="526"/>
        <location filename="../mainwindow.cpp" line="1346"/>
        <location filename="../mainwindow.cpp" line="1359"/>
        <location filename="../mainwindow.cpp" line="1365"/>
        <source>Error</source>
        <translation>Ocorreu um Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Instalando a tela de inicialização. Por favor, aguarde a finalização do processo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>Updating sources</source>
        <translation>Atualizando as fontes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>Could not install the bootsplash.</source>
        <translation>Não foi possível instalar a tela de inicialização</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Could not create a temporary folder</source>
        <translation>Não foi possível criar uma pasta temporária</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="535"/>
        <location filename="../mainwindow.cpp" line="555"/>
        <source>Cannot continue</source>
        <translation>Não é possível continuar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="535"/>
        <source>Cannot open LUKS device. Exiting...</source>
        <translation>Não foi possível abrir o dispositivo com LUKS. Saindo do programa...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="556"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Não é possível criar o ambiente ‘chroot’, não é possível alterar as opções de inicialização. Saindo do programa...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="887"/>
        <location filename="../mainwindow.cpp" line="1266"/>
        <source>Updating configuration, please wait</source>
        <translation>Atualizando a configuração. Por favor, aguarde a finalização do processo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="958"/>
        <source>Updating initramfs...</source>
        <translation>Atualizando o ‘initramfs’...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="972"/>
        <location filename="../mainwindow.cpp" line="1281"/>
        <source>Updating grub...</source>
        <translation>Atualizando o Grub...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="997"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="998"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1000"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Programa para selecionar as opções comuns de inicialização</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1002"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) do MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1003"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1024"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1034"/>
        <location filename="../mainwindow.cpp" line="1243"/>
        <source>Running in a Virtual Machine</source>
        <translation>Executando em uma Máquina Virtual</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1035"/>
        <location filename="../mainwindow.cpp" line="1244"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>O seu sistema atual está sendo executado a partir de
uma Máquina Virtual, a tela do ‘Plymouth’ funcionará
de forma limitada, você também não poderá visualizar
o tema.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1042"/>
        <source>Plymouth packages not installed</source>
        <translation>Os pacotes do ‘Plymouth’ não estão instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1043"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Os pacotes do ‘Plymouth’ não estão instalados no sistema operacional.
Você quer continuar e instalar os pacotes do ‘Plymouth’?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1069"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Imagens (*.png, *.jpg, *.jpeg ou *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1211"/>
        <source>Log not found</source>
        <translation>O relatório das alterações não foi encontrado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1211"/>
        <source>Could not find log at </source>
        <translation>Não foi possível encontrar o relatório das alterações em</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1346"/>
        <source>Could not retrieve UUID for %1</source>
        <translation>Não foi possível recuperar o UUID para o %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1354"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Inserir a senha para desbloquear a partição criptografada/encriptada %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1359"/>
        <source>Password entry cancelled or empty for %1</source>
        <translation>O campo de entrada da senha está cancelado ou está vazio para o %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1365"/>
        <source>Could not open %1 LUKS container</source>
        <translation>Não foi possível abrir o contêiner do LUKS %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1200"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="100"/>
        <source>A process is still running. Do you really want to quit?</source>
        <translation>Existe um outro processo que está em execução. Você realmente quer sair?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="167"/>
        <source>Live System Detected</source>
        <translation>Sistemas Executáveis que Foram Detectados</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="169"/>
        <source>You are currently running a live system. Would you like to modify the boot options for the live system or for an installed system?</source>
        <translation>Você está executando um sistema operacional a partir de um dispositivo executável (CD, DVD, USB, etc.). Você quer modificar as opções de inicialização para o sistema do dispositivo executável ou de um sistema que esteja instalado?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>Live System</source>
        <translation>Sistema Operacional Executável</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="172"/>
        <source>Installed System</source>
        <translation>Sistema Operacional Instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="373"/>
        <source>Failed to update package sources.</source>
        <translation>Ocorreu uma falha ao atualizar as fontes do pacote.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>Installing packages:</source>
        <translation>Instalando os pacotes:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="387"/>
        <source>Success</source>
        <translation>O processo foi concluído com sucesso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="387"/>
        <source>Bootsplash installed successfully.</source>
        <translation>A tela de inicialização foi instalada com sucesso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>Failed to create temporary file.</source>
        <translation>Ocorreu uma falha ao criar o arquivo temporário.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>You are currently running in live mode with the &apos;toram&apos; option. Please remember to save the persistence file or remaster, otherwise any changes made will be lost.</source>
        <translation>No momento, você está executando um sistema operacional que foi iniciado a partir de um dispositivo executável (CD, DVD, USB, etc.) com a opção ‘toram’ (para a memória RAM) ativada na inicialização. Lembre-se de salvar o arquivo de persistência ou de remasterizar o dispositivo USB executável, caso contrário, quaisquer alterações tenham sido feitas serão perdidas.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="982"/>
        <source>Your changes have been successfully applied.</source>
        <translation>As suas alterações foram aplicadas com sucesso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="983"/>
        <source>Operation Complete</source>
        <translation>O processo foi concluído com sucesso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1068"/>
        <source>Select image to display in bootloader</source>
        <translation>Selecione a imagem para exibir no carregador de inicialização (bootloader)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1192"/>
        <source>Boot Log</source>
        <translation>Relatório das alterações da inicialização</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1232"/>
        <source>Needs reboot</source>
        <translation>É necessário reinicializar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1233"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>O ‘Plymouth’ foi instalado com sucesso, pode ser necessário reiniciar o sistema operacional antes de poder exibir as pré-visualizações</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1302"/>
        <source>Click to select theme</source>
        <translation>Clique para selecionar o tema</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1313"/>
        <source>Select GRUB theme</source>
        <translation>Selecionar o tema do GRUB</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Program for selecting common start-up choices</source>
        <translation>O ‘MX Boot Options’ permite alterar as opções relacionadas ao menu de inicialização do Grub (gerenciador de inicialização ou carregador de inicialização), configurar o tempo limite de exibição do menu do Grub (o padrão são 5 segundos nos sistemas operacionais instalados), configurar e reinstalar a tela de inicialização do Grub, alterar a entrada padrão de inicialização do menu do Grub, alterar a imagem e o tema do menu do Grub, ativar a seleção de inicialização nos sistemas instalados, alterar as opções de inicialização do UEFI, excluir uma ou mais entradas do menu de inicialização, entre outras opções comuns de inicialização</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="55"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="56"/>
        <location filename="../about.cpp" line="65"/>
        <source>Changelog</source>
        <translation>Relatório das Alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="57"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="76"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>Ocorreu um erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Ao que parece, você está conectado como usuário ‘root’ (administrador). Por favor, saia da sessão e entre novamente com o usuário normal para utilizar este programa.</translation>
    </message>
</context>
</TS>